==> qt6-positioning-6.5.0-1-armv7h.pkg.tar.xz: usr/lib/cmake/Qt6Positioning/Qt6QGeoPositionInfoSourceFactoryGeoclue2PluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QGeoPositionInfoSourceFactoryGeoclue2Plugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELWITHDEBINFO)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin)
get_target_property(_qt_imported_location Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin IMPORTED_LOCATION_RELWITHDEBINFO)
get_target_property(_qt_imported_location_default Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin" for configuration "Release"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin PROPERTY IMPORTED_LOCATION_RELEASE "${_qt_imported_location}")
endif()

# Import target "Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_configs)

==> qt6-positioning-6.7.2-1-armv7h.pkg.tar.xz: usr/lib/cmake/Qt6Positioning/Qt6QGeoPositionInfoSourceFactoryGeoclue2PluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QGeoPositionInfoSourceFactoryGeoclue2Plugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELWITHDEBINFO)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin)
get_target_property(_qt_imported_location Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin IMPORTED_LOCATION_RELWITHDEBINFO)
get_target_property(_qt_imported_location_default Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin" for configuration "Release"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin PROPERTY IMPORTED_LOCATION_RELEASE "${_qt_imported_location}")
endif()

# Import target "Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryGeoclue2Plugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_objects)
unset(_qt_imported_objects_default)
unset(_qt_imported_clr)
unset(_qt_imported_clr_default)
unset(_qt_imported_configs)
